@@ -25,23 +25,27 @@ populse_mia.
 ##########################################################################
 
 # mia_processes import
-from mia_processes.process_mia import Process_Mia
+#from mia_processes.process_mia import Process_Mia
+from populse_mia.user_interface.pipeline_manager.process_mia import ProcessMIA
 from .nipype_extension import NewSegmentMia
 
 # populse_mia import
 from populse_mia.software_properties import Config
+from soma.controller.trait_utils import relax_exists_constraint
 
 # nipype import
 from nipype.interfaces import spm
-from nipype.interfaces.base import OutputMultiPath, InputMultiPath, File, traits
+from nipype.interfaces.base import (OutputMultiPath, InputMultiPath, File,
+                                    InputMultiObject, traits_extension)
 from nipype.interfaces.spm.base import ImageFileSPM
 
 # Other import
 import os
 from traits.api import Undefined, Float
+import traits.api as traits
 from pathlib import Path
 
-class Coregister(Process_Mia):
+class Coregister(ProcessMIA):
     """
     *Align together scans of different modalities*
 
@@ -50,6 +54,11 @@ class Coregister(Process_Mia):
 
     """
 
+    use_mcr = traits.Bool(optional=True, userlevel=1)
+    paths = InputMultiObject(traits.Directory(), optional=True, userlevel=1)
+    matlab_cmd = traits_extension.Str(optional=True, userlevel=1)
+    mfile = traits.Bool(optional=True, userlevel=1)
+
     def __init__(self):
         """Dedicated to the attributes initialisation / instanciation.
         
@@ -61,7 +70,7 @@ class Coregister(Process_Mia):
         super(Coregister, self).__init__()
 
         # Third party softwares required for the execution of the brick
-        self.requirement = ['matlab', 'spm']
+        self.requirement = ['spm']
 
         # Inputs description
         target_desc = ('The reference file to register to. An existing,'
@@ -342,6 +351,19 @@ class Coregister(Process_Mia):
     def run_process_mia(self):
         """Dedicated to the process launch step of the brick."""
         super(Coregister, self).run_process_mia()
+
+        if (self.target and self.source and
+                self.source != [Undefined] and self.jobtype):
+            self.process.inputs.target = self.target
+            self.process.inputs.source = self.source
+            self.process.inputs.jobtype = self.jobtype
+
+            if self.apply_to_files and self.apply_to_files != [Undefined]:
+                self.process.inputs.apply_to_files = self.apply_to_files
+
+            if self.out_prefix:
+                self.process.inputs.out_prefix = self.out_prefix
+
         self.process.inputs.target = self.target
         self.process.inputs.source = self.source
         self.process.inputs.apply_to_files = self.apply_to_files
@@ -354,7 +376,7 @@ class Coregister(Process_Mia):
         self.process.run()
 
 
-class NewSegment(Process_Mia):
+class NewSegment(ProcessMIA):
     """
     *Segmentation: Segments,  bias  corrects  and  spatially normalises - all in the same model*
 
@@ -363,6 +385,11 @@ class NewSegment(Process_Mia):
 
     """
 
+    use_mcr = traits.Bool(optional=True, userlevel=1)
+    paths = InputMultiObject(traits.Directory(), optional=True, userlevel=1)
+    matlab_cmd = traits_extension.Str(optional=True, userlevel=1)
+    mfile = traits.Bool(optional=True, userlevel=1)
+
     def __init__(self):
         """Dedicated to the attributes initialisation / instanciation.
         
@@ -374,7 +401,7 @@ class NewSegment(Process_Mia):
         super(NewSegment, self).__init__()
 
         # Third party softwares required for the execution of the brick
-        self.requirement = ['matlab', 'spm']
+        self.requirement = ['spm']
 
         # Inputs description
         
@@ -450,16 +477,18 @@ class NewSegment(Process_Mia):
         config = Config()
         resources_path = os.path.join(config.get_mia_path(), 'resources')
         tpm_path = os.path.join(resources_path, 'spm12', 'tpm', 'TPM.nii')
-        
-        if not Path(tpm_path).exists():
-            print('\n The {} file seems to not exists ...'.format(tpm_path))
 
-        tissues_list = [((tpm_path, 1), 2, (True, False), (False, False)),
-                        ((tpm_path, 2), 2, (True, False), (False, False)),
-                        ((tpm_path, 3), 2, (True, False), (False, False)),
-                        ((tpm_path, 4), 3, (True, False), (False, False)),
-                        ((tpm_path, 5), 4, (True, False), (False, False)),
-                        ((tpm_path, 6), 2, (True, False), (False, False))]
+        if not Path(tpm_path).is_file():
+            print('\nThe {} file seems to not exists ...'.format(tpm_path))
+            tissues_list = Undefined
+
+        else:
+            tissues_list = [((tpm_path, 1), 2, (True, False), (False, False)),
+                            ((tpm_path, 2), 2, (True, False), (False, False)),
+                            ((tpm_path, 3), 2, (True, False), (False, False)),
+                            ((tpm_path, 4), 3, (True, False), (False, False)),
+                            ((tpm_path, 5), 4, (True, False), (False, False)),
+                            ((tpm_path, 6), 2, (True, False), (False, False))]
 
         # Inputs traits
         self.add_trait("channel_files",
@@ -482,17 +511,19 @@ class NewSegment(Process_Mia):
                                     desc=channel_info_desc))
 
         self.add_trait("tissues",
-                       traits.List(
-                           traits.Tuple(
-                               traits.Tuple(ImageFileSPM(exists=True),
-                                            traits.Int()),
-                               traits.Int(),
-                               traits.Tuple(traits.Bool, traits.Bool),
-                               traits.Tuple(traits.Bool, traits.Bool)),
-                           value=tissues_list,
+                       traits.Either(
+                           traits.List(
+                               traits.Tuple(
+                                   traits.Tuple(ImageFileSPM(exists=True),
+                                                traits.Int()),
+                                   traits.Int(),
+                                   traits.Tuple(traits.Bool, traits.Bool),
+                                   traits.Tuple(traits.Bool, traits.Bool))),
+                           Undefined,
                            output=False,
                            optional=True,
                            desc=tissues_desc))
+        self.tissues = tissues_list
 
         self.add_trait("warping_regularization",
                        traits.Either(traits.List(traits.Float(),
@@ -572,9 +603,10 @@ class NewSegment(Process_Mia):
                                        desc=inverse_deformation_field_desc))
 
         self.add_trait("forward_deformation_field",
-                       ImageFileSPM(output=True,
-                                    optional=True,
-                                    desc=forward_deformation_field_desc))
+                       OutputMultiPath(ImageFileSPM(),
+                                       output=True,
+                                       optional=True,
+                                       desc=forward_deformation_field_desc))
 
         self.add_trait("transformation_mat",
                        OutputMultiPath(File(),
@@ -671,6 +703,20 @@ class NewSegment(Process_Mia):
     def run_process_mia(self):
         """Dedicated to the process launch step of the brick."""
         super(NewSegment, self).run_process_mia()
+
+        if self.channel_files:
+            self.process.inputs.channel_files = self.channel_files
+
+            if self.channel_info:
+                self.process.inputs.channel_info = self.channel_info
+
+            if self.write_deformation_fields:
+                (self.process.inputs.
+                    write_deformation_fields) = self.write_deformation_fields
+
+            if self.tissues:
+                self.process.inputs.tissues = self.tissues
+
         self.process.inputs.channel_files = self.channel_files
         self.process.inputs.channel_info = self.channel_info
         self.process.inputs.tissues = self.tissues
@@ -682,7 +728,7 @@ class NewSegment(Process_Mia):
         self.process.run()
 
 
-class Normalize12(Process_Mia):
+class Normalize12(ProcessMIA):
     """    
     *Computes the warp that best aligns the template (atlas) to the individual’s image*
 
@@ -691,6 +737,11 @@ class Normalize12(Process_Mia):
 
     """
     
+    use_mcr = traits.Bool(optional=True, userlevel=1)
+    paths = InputMultiObject(traits.Directory(), optional=True, userlevel=1)
+    matlab_cmd = traits_extension.Str(optional=True, userlevel=1)
+    mfile = traits.Bool(optional=True, userlevel=1)
+
     def __init__(self):
         """Dedicated to the attributes initialisation / instanciation.
         
@@ -702,7 +753,7 @@ class Normalize12(Process_Mia):
         super(Normalize12, self).__init__()
 
         # Third party softwares required for the execution of the brick
-        self.requirement = ['matlab', 'spm']
+        self.requirement = ['spm']
 
         # Inputs description
         image_to_align_desc = ('The image that the atlas data is warped into '
@@ -770,8 +821,8 @@ class Normalize12(Process_Mia):
         resources_path = os.path.join(config.get_mia_path(), 'resources')
         tpm_path = os.path.join(resources_path, 'spm12', 'tpm', 'TPM.nii')
         
-        if not Path(tpm_path).exists():
-            print('\n The {} file seems to not exists ...'.format(tpm_path))
+        if not Path(tpm_path).is_file():
+            print('\nThe {} file seems to not exists ...'.format(tpm_path))
             tpm_path = Undefined
 
         # Inputs traits
@@ -914,6 +965,9 @@ class Normalize12(Process_Mia):
         # process instanciation
         self.process = spm.Normalize12()
         self.change_dir = True
+        # fix an output trait marked as exists
+        relax_exists_constraint(self.process.output_spec().trait(
+            'normalized_files'))
 
     def list_outputs(self, is_plugged=None):
         """Dedicated to the initialisation step of the brick.
@@ -1025,6 +1079,26 @@ class Normalize12(Process_Mia):
         """Dedicated to the process launch step of the brick."""
         super(Normalize12, self).run_process_mia()
 
+        self.process.inputs.jobtype = self.jobtype
+
+        if ((self.apply_to_files) and (self.apply_to_files != [Undefined]) and
+                         (self.deformation_file)
+                         and (self.jobtype == 'write')):
+            self.process.inputs.apply_to_files = self.apply_to_files
+            self.process.inputs.deformation_file = self.deformation_file
+
+        elif (self.image_to_align) and (self.tpm) and (self.jobtype == 'est'):
+            self.process.inputs.image_to_align = self.image_to_align
+            self.process.inputs.tpm = self.tpm
+
+        elif ((self.image_to_align) and (self.tpm) and
+                                                (self.jobtype == 'estwrite')):
+            self.process.inputs.image_to_align = self.image_to_align
+            self.process.inputs.tpm = self.tpm
+
+            if (self.apply_to_files) and (self.apply_to_files != [Undefined]):
+                self.process.inputs.apply_to_files = self.apply_to_files
+
         if self.jobtype == 'write':
             self.process.inputs.write_bounding_box = self.write_bounding_box
             self.process.inputs.write_voxel_sizes = self.write_voxel_sizes
@@ -1058,7 +1132,7 @@ class Normalize12(Process_Mia):
         self.process.run()
 
 
-class Realign(Process_Mia):
+class Realign(ProcessMIA):
     """
     *Realigns a time-series of images acquired from the same subject*
 
@@ -1067,6 +1141,11 @@ class Realign(Process_Mia):
 
     """
     
+    use_mcr = traits.Bool(optional=True, userlevel=1)
+    paths = InputMultiObject(traits.Directory(), optional=True, userlevel=1)
+    matlab_cmd = traits_extension.Str(optional=True, userlevel=1)
+    mfile = traits.Bool(optional=True, userlevel=1)
+
     def __init__(self):
         """Dedicated to the attributes initialisation / instanciation.
         
@@ -1078,7 +1157,7 @@ class Realign(Process_Mia):
         super(Realign, self).__init__()
 
         # Third party softwares required for the execution of the brick
-        self.requirement = ['matlab', 'spm']
+        self.requirement = ['spm']
         
         # Inputs description
         in_files_desc = ('The images to realign (a list of pathlike objects or '
@@ -1404,6 +1483,13 @@ class Realign(Process_Mia):
     def run_process_mia(self):
         """Dedicated to the process launch step of the brick."""
         super(Realign, self).run_process_mia()
+
+        if self.in_files and self.in_files != [Undefined]:
+            self.process.inputs.in_files = self.in_files
+
+            if self.out_prefix:
+                self.process.inputs.out_prefix = self.out_prefix
+
         self.process.inputs.in_files = self.in_files
         self.process.inputs.jobtype = self.jobtype
         self.process.inputs.quality = self.quality
@@ -1421,7 +1507,7 @@ class Realign(Process_Mia):
         self.process.run()
 
         
-class Smooth(Process_Mia):
+class Smooth(ProcessMIA):
     """
     *3D Gaussian smoothing of image volumes*
 
@@ -1430,6 +1516,11 @@ class Smooth(Process_Mia):
 
     """
 
+    use_mcr = traits.Bool(optional=True, userlevel=1)
+    paths = InputMultiObject(traits.Directory(), optional=True, userlevel=1)
+    matlab_cmd = traits_extension.Str(optional=True, userlevel=1)
+    mfile = traits.Bool(optional=True, userlevel=1)
+
     def __init__(self):
         """Dedicated to the attributes initialisation / instanciation.
         
@@ -1441,7 +1532,7 @@ class Smooth(Process_Mia):
         super(Smooth, self).__init__()
 
         # Third party softwares required for the execution of the brick
-        self.requirement = ['matlab', 'spm']
+        self.requirement = ['spm']
 
         # Inputs description
         in_files_desc = ('List of files to smooth. A list of items which are '
@@ -1578,9 +1669,15 @@ class Smooth(Process_Mia):
     def run_process_mia(self):
         """Dedicated to the process launch step of the brick."""
         super(Smooth, self).run_process_mia()
-        
+
+        if self.in_files and self.in_files != [Undefined]:
+            self.process.inputs.in_files = self.in_files
+
+            if self.out_prefix:
+                self.process.inputs.out_prefix = self.out_prefix
+
         for idx, element in enumerate(self.in_files):
-            full_path = os.path.relpath(element)
+            full_path = os.path.abspath(element)
             self.in_files[idx] = full_path
 
         self.process.inputs.in_files = self.in_files
